<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.UI.Notifications.Preview

Windows Runtime (WinRT) APIs for for the `Windows.UI.Notifications.Preview` namespace.

This package provides the `winrt.windows.ui.notifications.preview` module.
